#
# spec file for package guile
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# define the name used for versioning libs and directories.
%define guilemaj    3
%define guilemin    0
%define guilevers   %{guilemaj}.%{guilemin}
%define libgver     1
%define gsuff       %{guilemaj}_%{guilemin}-%{libgver}
Name:           guile
Version:        %{guilevers}.9
Release:        2.1
Summary:        GNU's Ubiquitous Intelligent Language for Extension
License:        GFDL-1.3-only AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Languages/Scheme
URL:            https://www.gnu.org/software/guile/
Source0:        https://ftp.gnu.org/gnu/guile/%{name}-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/guile/%{name}-%{version}.tar.xz.sig
# key: 4FD4D288D445934E0A14F9A5A8803732E4436885 as from the release notes
Source2:        %{name}.keyring
# Fix the resulting /usr/lib64/pkgconfig/guile-3.0.pc
Patch0:         guile-3.0-gc_pkgconfig_private.patch
# The out-of-memory test is flaky, so disable it
Patch1:         disable-test-out-of-memory.patch
Patch2:         gcc10-x86-disable-one-test.patch
Patch3:         adjust-32bit-big-endian-build-flags.patch
# do sequential build for reproducible .go files = https://issues.guix.gnu.org/issue/20272 - boo#1102408
Patch4:         stage2-serialize.patch
BuildRequires:  gmp-devel
BuildRequires:  libffi-devel
BuildRequires:  libltdl-devel
BuildRequires:  libunistring-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(bdw-gc)
Requires(pre):  fileutils
Requires(pre):  sh-utils

%description
This is Guile, a portable, embeddable Scheme implementation written in
C. Guile provides a machine independent execution platform that can be
linked in as a library when building extensible programs.

%package -n libguile-%{gsuff}
Summary:        GNU's Ubiquitous Intelligent Language for Extension
License:        GFDL-1.3-only AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Languages/Scheme
Requires:       %{name}-modules-%{guilemaj}_%{guilemin} >= %{version}
# workaround for bnc#948804
Requires:       glibc-locale

%description -n libguile-%{gsuff}
This is Guile, a portable, embeddable Scheme implementation written in
C. Guile provides a machine independent execution platform that can be
linked in as a library when building extensible programs. This package
contains the shared libraries.

%package modules-%{guilemaj}_%{guilemin}
Summary:        GNU's Ubiquitous Intelligent Language for Extension
License:        GFDL-1.3-only AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Languages/Scheme

%description modules-%{guilemaj}_%{guilemin}
This is Guile, a portable, embeddable Scheme implementation written in
C. Guile provides a machine independent execution platform that can be
linked in as a library when building extensible programs. This package
contains guile modules.

%package devel
Summary:        GNU's Ubiquitous Intelligent Language for Extension
License:        LGPL-2.1-or-later
Group:          Development/Languages/Scheme
Requires:       gmp-devel
# following Requires needed because /usr/bin/guile-config needs /usr/bin/guile
Requires:       guile = %{version}
Requires:       libffi-devel
Requires:       libguile-%{gsuff} = %{version}
Requires:       libunistring-devel
Requires:       ncurses-devel
Requires:       readline-devel
Requires:       pkgconfig(bdw-gc)

%description devel
This is Guile, a portable, embeddable Scheme implementation written in
C. Guile provides a machine independent execution platform that can be
linked in as a library when building extensible programs.

%prep
%autosetup -p1

# remove broken prebuilt objects
rm -r prebuilt/32-bit-big-endian

%if 0%{?qemu_user_space_build}
# QEMU ignores rlimit requests for setting RLIMIT_AS
echo exit 77 > test-suite/standalone/test-stack-overflow
%endif

%build
autoreconf -fi
%configure \
  --disable-static \
  --with-pic \
  --enable-lto \
  --with-threads \
  --disable-silent-rules
%make_build

%check
# user mode emulation needs additional fds that
# the testsuite is not expecting
%if ! 0%{?qemu_user_space_build}
LD_LIBRARY_PATH="." \
%make_build check
%endif

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/guile/site
find %{buildroot} -type f -name "*.la" -delete -print
# bug #874028
mkdir -p %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}
mv %{buildroot}%{_libdir}/libguile*-gdb.scm %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}/

%pre
# Remove obsolete files (< SuSE Linux 10.2)
rm -f var/adm/SuSEconfig/md5%{_datadir}/guile/*/slibcat
rm -f usr/share/guile/site/slibcat.SuSEconfig

%post -n libguile-%{gsuff} -p /sbin/ldconfig
%postun -n libguile-%{gsuff} -p /sbin/ldconfig

%files
%doc ABOUT-NLS AUTHORS ChangeLog GUILE-VERSION HACKING
%doc NEWS README THANKS
%{_bindir}/guile-tools
%{_bindir}/guild
%{_bindir}/guile
%{_mandir}/man1/guile.1%{?ext_man}

%files -n libguile-%{gsuff}
%license LICENSE COPYING*
%{_libdir}/libguile-%{guilevers}.so.%{libgver}*

%files modules-%{guilemaj}_%{guilemin}
%{_libdir}/%{name}
# Own usr/share/guile/site; side effect of not doing so is slib failing to install correctly.
%{_datadir}/%{name}

%files devel
%{_bindir}/guile-snarf
%{_bindir}/guile-config
%dir %{_includedir}/%{name}
%dir %{_includedir}/%{name}/%{guilevers}
%{_includedir}/%{name}/%{guilevers}/*
%{_datadir}/aclocal/guile.m4
%{_infodir}/%{name}.info%{?ext_info}
%{_infodir}/%{name}.info-[0-9]%{ext_info}
%{_infodir}/%{name}.info-1[0-9]%{ext_info}
%{_infodir}/r5rs.info%{?ext_info}
%{_libdir}/libguile-%{guilevers}.so
%{_libdir}/pkgconfig/guile-%{guilevers}.pc
# bug #874028
%dir %{_datadir}/gdb
%dir %{_datadir}/gdb/auto-load
%dir %{_datadir}/gdb/auto-load%{_prefix}
%dir %{_datadir}/gdb/auto-load/%{_libdir}
%{_datadir}/gdb/auto-load/%{_libdir}/libguile*-gdb.scm

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Tue May 23 2023 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Add key from Ludovic Courtès to guile.keyring, who released 3.0.9
* Sun Jan 29 2023 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to version 3.0.9
  * New interfaces and functionality
  * * New `spawn' procedure to spawn child processes
  * * `open-file' now supports an "e" flag for O_CLOEXEC
  * * `pipe' now takes flags as an optional argument
  * * Bindings to `openat' and friends
  * * Abstract Unix-domain sockets are supported
  * * New socket-related constants defined
  * * New `bytevector-slice' procedure
  * * Disassembler now shows intrinsic names
  * * Linker and assembler consume less memory
  * Bug fixes (for more see the NEWS file)
  * * JIT compilation is now supported on Apple M1 processors
  * * libguile/srfi-14.i.c is now longer shipped and is instead built from source
  * * Cross-compilation supports triplets with empty vendor strings
  * * 'system*' honors output/error port redirects
    (https://bugs.gnu.org/52835)
  * * 'open-input-pipe' & co. are now much faster
    (https://bugs.gnu.org/59321)
- Refresh patches:
  * disable-test-out-of-memory.patch
  * guile-3.0-gc_pkgconfig_private.patch
- Remove no longer used guile-rpmlintrc
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- skip checks for qemu-user-space-builds (tries to close filedescriptors
  that qemu relies on)
* Tue Mar 29 2022 Andreas Schwab <schwab@suse.de>
- stage2-serialize.patch: Serialize stage2 build only
* Mon Mar 21 2022 Dirk Müller <dmueller@suse.com>
- use parallel build for Rings
- force LTO
* Mon Mar 21 2022 Andreas Schwab <schwab@suse.de>
- adjust-32bit-big-endian-build-flags.patch: replace with working patch
* Mon Mar  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add patch to fix build on 32-bit big-endian targets
  * adjust-32bit-big-endian-build-flags.patch
- Run aclocal before %%configure to regenerate aclocal.m4
* Thu Feb 24 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.0.8
  * Important changes
  * Avoid the need for a custom GMP allocator
    This removes the need for the GUILE_INSTALL_GMP_MEMORY_FUNCTIONS
    environment variable mentioned introduced with Guile 3.0.6
    And deprecates the scm_install_gmp_memory_functions variable.
  * New interfaces and functionality
  * Typed vector copy functions in srfi srfi-4 gnu
    See SRFI-4 - Guile extensions" in the manual.
  * `bytevector-fill!' supports partial fill through optional arguments
  * `vector-copy!' and `vector-copy' from (rnrs base) included in core
  * New function bitvector-copy
  * Other new optimizations
  * Better optimization of "let" in right-hand-side of "letrec"
  * Allow constant-folding for calls to "expt"
  * Add ,optimize-cps REPL meta-command
  * Improve alias analysis in common subexpression elimination
  * Avoid argument-count checks for well-typed calls to known procedures
  * Avoid return-value-count checks for calls to
    known-return-arity procedures
  * New deprecations
  * Vector functions require vector arguments
  * `scm_from_contiguous_typed_array' is deprecated
  * Deprecate the "simple vector" concept, `scm_is_simple_vector'
  * Deprecate internal contiguous array flag
  * Deprecate symbol properties
    Symbols used to have a "function slot" and a "property slot"
  * Bug fixes
  * Fix compilation of (ash x N), where N is a literal, at -O1 and below
  * Texinfo and XML parsers are now thread-safe
  * Fix crash when reading #nil
  * Limit `ash' to left-shift by 2^32 bits
  * Various other bug fixes, please refer to the NEWS file
- Drop upstream fixed
  0007-Fix-non-revealed-port-is-closed-ports.test.patch
- Drop upstream fixed (commit b4a80f4239b19fea4d2cc3e9d197f24b809f0624)
  gnulib-dynarray.patch
* Tue Sep  7 2021 Andreas Schwab <schwab@suse.de>
- gnulib-dynarray.patch: Update gnulib module dynarray to fix use of
  reserved macros
* Fri May 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.0.7
  * Guile now defines constants such as `O_NOFOLLOW', `O_CLOEXEC',
    `O_TMPFILE', and more.  These may be passed as arguments to
    procedures such as `open' and `open-fdes'.
  * Fix deadlock after `primitive-fork'
  * Fix duplicates handlers for interfaces that use interfaces
  * Fix R7RS include-library-declarations, cond-expand
  * Fix excessive compile times for vectors >16k elements long
  * Fix use of literal tree-il as source language
  * Fix SRFI-64 test-end to not remove globally-installed test runner
- Update to version 3.0.6
  * Reimplement dynamic library loading ("dlopening") without libltdl
  * New library search path variable, `GUILE_EXTENSIONS_PATH'.
  * Fix important incompatibility with GnuTLS and GMP, but this may
    slow down some uses of bignums.
  * New `read' implementation in Scheme
  * Syntax objects record source locations
  * Optimized run-time relocations
  * Optimized calls to known functions
  * Reduce code size for calls to module variables
  * Updated Gnulib
  * New interfaces and functionality
  * `call-with-port'
  * `call-with-input-bytevector', `call-with-output-bytevector'
  * `mkdtemp' and `mkstemp'
  * `(system foreign-library)' module
  * `read-syntax'
  * `quote-syntax'
  * `syntax-sourcev'
  * Fix reverse-list->string docstring
  * Fix R7RS "member" result when no item found
  * Fix make-transcoded-port on input+output ports
  * Fix (ice-9 ftw) on filesystems where inode values are meaningless
  * Fix srfi-69 merge-hash
  * Fix suspendable-ports implementation of get-bytevector-some!
  * Fix overread in string-locale<?, string-locale-ci<?, and friends
  * Fix handling of parameter lists to elisp defun to allow nil
  * Fix closure-conversion bug for SCC with no free vars and one
    not-well-known function
  * Fix error when < passed non-real value
  * Fix bug in which exported and private names in a used module
    could alias each other
  * Fix bug with slot options in redefinable GOOPS classes
  * Fix bugs regarding port buffering for TLS connections in web client
  * `dynamic-unlink': Deprecated! has now no effect
  * `call-with-output-string': Changed! closes port on normal exit
- Update disable-test-out-of-memory.patch
- Add 0007-Fix-non-revealed-port-is-closed-ports.test.patch from
  Debian
* Fri Jan 22 2021 Andreas Schwab <schwab@suse.de>
- Skip test-stack-overflow on qemu builds
* Sat Jan  9 2021 Andreas Stieger <andreas.stieger@gmx.de>
- GNU guile 3.0.5:
  * O(1) compilation of `case' and related expressions
  * New (ice-9 copy-tree) module
  * New warning: use-before-definition
  * New warning: non-idempotent-definition
  * A number of functions were deprecated with replacements
  * copy read-option removed
- remove deprecated texinfo packaging macros
* Thu Jun 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- guile 3.0.4:
  * SONAME fix (relative to 3.0.3)
- includes changes from 3.0.3:
  * New baseline compiler
  * New VM intrinsics to support baseline compiler
  * Compiler support for warning and lowering passes
  * Compiler support for choosing different compilation orders
  * Better support for specifying optimization and warning levels
  * Faster Guile build from source
  * New 'pipeline' procedure in (ice-9 popen)
  * Refreshed bitvector facility
  * New bitvector-count, bitvector-count-bits, bitvector-position
    procedures
  * New bitvector-bit-set?, bitvector-bit-clear? procedures
  * New bitvector-set-bit!, bitvector-clear-bit! procedures
  * New bitvector-set-all-bits!, bitvector-clear-all-bits! procedures
  * New bitvector-flip-all-bits! procedure
  * New bitvector-set-bits!, bitvector-clear-bits! procedures
  * various bug fixes
  * deprecations: Old bitvector interfaces, accessing generic
    arrays using the bitvector procedures, scm_istr2bve
* Tue May  5 2020 Martin Liška <mliska@suse.cz>
- Add gcc10-x86-disable-one-test.patch in order to fix
  boo#1170836.
* Fri Mar 27 2020 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to version 3.0.2:
  Changes compared to 3.0.1:
  * New (srfi srfi-171) module
  * Fix heap corruption when allocating structs (caused problems when
    building Guix on openSUSE)
  * Fix race condition between 'abort-to-prompt' and stack marking
  * Ensure weak sets are occasionally vacuumed
  * Interpret dynamic library name as literal file name first
  * <libguile.h> includes <libguile/hooks.h> again
  * Fix fixpoint computation in compute-significant-bits
  * Fix compilation '--without-threads'
  * 'tmpnam' is now deprecated
- Remove patch:
  * guile-3.0-fix-compile-crash.patch: patch included in release
* Sun Mar 22 2020 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Add patch from upstream to fix build of Guix with more then two threads:
  * guile-3.0-fix-compile-crash.patch
* Mon Mar  9 2020 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 3.0.1:
  Changes compared to 3.0.0:
  * Export constructor and predicate for '&quit-exception'
  * (texinfo plain-text) now exports '*line-width*' fluid
  * R7RS support recognizes the '.sld' extension
  * 'hash' correctly handles keywords, ports, hash tables, etc.
  * 'include' no longer rejects relative file names
  * Reduce GC pressure when using bignums
  * Fix expansion of 'error' calls with a non-constant argument
  * Improve source location information for top-level references
  * Web client treats TLS "premature termination" error as EOF
  * Fix bug restoring a JIT continuation from the interpreter
  * Export C symbols 'scm_sym_lambda', 'scm_sym_quote', etc. again
  * Fix build on IA64 and on platforms where the stack grows upwards
  * texinfo properly renders @acronym in plain text
  * Compiler now optimizes (logior 0 INT)
  * Fix Readline configure check for the sake of libedit
  * Provided 'GUILE_PKG' Autoconf macro now detects Guile 3.0
* Thu Jan 16 2020 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 3.0.0:
  Major changes compared to 2.2.x:
  * Just-in-time code generation on x86_64, i586, armv7l, and aarch64
  * Lower-level bytecode
  * Add support for R7RS
  * Interleaved internal definitions and expressions allowed
  * Record unification
  * Reimplementation of exceptions to be more aligned with R6RS-style
  * `guard' no longer unwinds the stack for clause tests
  * Optimization of top-level bindings within a compilation unit (-O3
    is now differnt then -O2)
  * By default, GOOPS classes are not redefinable
  * Define top-level bindings for aux syntax: `else', `=>', `...', `_'
  * Conventional gettext alias is now `G_'
  * Add --r6rs command-line option
  * Add #:re-export-and-replace argument to `define-module'
  * `define-module' #:autoload no longer pulls in the whole module
  * Improve SRFI-43 vector-fill!
  * `iota' in core and SRFI-1 `iota' are the same
  * Improved Transport Layer Security (TLS) support in (web client)
  * New deprecations
  * scm_t_uint8, etc deprecated in favor of C99 stdint.h
  * The two-argument form of `record-constructor'
  * Incompatible changes
  * All code deprecated in Guile 2.2 has been removed.
  * Remove "self" field from vtables and "redefined" field from
    classes
  * VM hook manipulation simplified
  * New effective version 3.0. pkg-config is now guile-3.0
  * Rename patch:
  * guile-2.2-gc_pkgconfig_private.patch to
    guile-3.0-gc_pkgconfig_private.patch: Adapt to 3.0 changes.
  * Set guilemaj to 3 and guilemin to 0
* Mon Sep 23 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Do sequential build for reproducible .go files (boo#1102408)
* Sat Jul  6 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 2.2.6
  Changes compared to 2.2.5:
  * Fix regression introduced in 2.2.5 that would break HTTP servers
  * 'strftime' and 'strptime' honor the current locale encoding
  * Re-export 'current-load-port'
  * Minor documentation mistakes were fixed
- remove patches:
  * revert-http-reader-change.patch: fix included in release
* Tue Jun 25 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 2.2.5
  Notable changes compared to 2.2.5:
  * Notable improvements
  * * Greatly improved performance of bidirectional pipes.
  * * New 'get-bytevector-some!' I/O primitive.
  * * get-bytevector-{n!,some,some!} now support suspendable I/O.
  * Compiler improvements
  * * guild compile: Add -Wshadowed-toplevel.
  * * guild compile: Add '-x' flag.
  * Miscellaneous improvements
  * * Bootstrap optimization
  * * put-u8 now always writes a single byte, regardless of the port encoding.
  * * Optimize fixnum exact integer square roots.
  * * scm_mkstrport: Optimize the POS -> BYTE_POS conversion.
  * * SRFI-19: Support ~N in string->date.
  * * SRFI-19: Update the leap second table.
  * * stexi->shtml: Add support for @i, @math, @tie and @dots.
  * * Define AT_SYMLINK_NOFOLLOW, AT_NO_AUTOMOUNT, and AT_EMPTY_PATH.
  * * Improvements to the 'time' macro from (ice-9 time).
  * Bug fixes
  * * Avoid regexp ranges in HTTP inter-protocol exploitation check.
  * * Fixes to the SRFI-19 time/date library.
  * * Improve overflow checks in bytevector, string, and I/O operations.
  * * Fix type inferencing for 'nil?' and 'null?' predicates.
  * * Fix 'atomic-box-compare-and-swap!'.
  * * Make URI handling locale independent.
  * * Strings, i18n: Limit the use of alloca to approximately 8 kilobytes.
  * * Fix documentation of R6RS 'binary-port?' to reflect reality.
  * * Avoid passing NULL to 'memcpy' and 'memcmp'.
  * * Save and restore errno in the signal handler.
  * * Various smaller bug fixes
  More details: /usr/share/doc/packages/guile/NEWS
- add patches:
  * revert-http-reader-change.patch: Fixes https://bugs.gnu.org/36350.
- remove patches:
  * guile-add-test-ja_JP.sjis.patch: proper fix included in 2.2.5
  * guile-use-utf8.patch: included in 2.2.5
  * disable-posix-crypt-test.patch: test succeeds now
- reorder patches
* Tue Jan 15 2019 schwab@suse.de
- remove broken prebuilt 32-bit big-endian objects
* Tue Nov 27 2018 jbrielmaier@suse.de
- Update to version 2.2.4. [boo#1117121]
  Notable changes compared to 2.0.14:
  * speed
  * better thread and space-safety
  * improved locale support
  * dynamically expandable stacks
  * many small improvements and bug fixes
  This release brings incompatible changes to 2.0.x versions.
  More details: /usr/share/doc/packages/guile/NEWS
- add patches:
  * disable-posix-crypt-test.patch: test glibc EINVAL fails
  * disable-test-out-of-memory.patch: heap error during test
- refresh patches:
  * guile-2.0.14-gc_pkgconfig_private.patch: rebase on guile 2.2
    and rename to guile-2.2-gc_pkgconfig_private.patch
- remove patches:
  * guile-64bit.patch
  * guile-1.6.10-mktemp.patch
  * guile-threads-test.patch
  * guile-net-db-test.patch: guile doesn't fail to build anymore
  * guile-disable-int-tests.patch: guile builds fine with glibc2.27
- reorder patches
- remove libguilereadline packages, as it became an extension
* Sun Oct 21 2018 psimons@suse.com
- Apply guile-use-utf8.patch to fix use of the "ja_JP.sjis" locale.
  [bsc#1110085]
- Apply guile-add-test-ja_JP.sjis.patch to add standalone test that
  verifies the "ja_JP.sjis" locale works properly. Further details
  at https://debbugs.gnu.org/cgi/bugreport.cgi?bug=33044#43.
  [bsc#1110085]
* Wed Feb 28 2018 tchvatal@suse.com
- Add back the require on gc-devel as it is still needed for the
  non .pc using packages (eg autotools)
* Wed Feb 28 2018 tchvatal@suse.com
- Add patch from Fedora not to link to libgc in all consumer libs:
  * guile-2.0.14-gc_pkgconfig_private.patch
- Add _constraints file to ensure we can build properly
* Wed Feb 28 2018 tchvatal@suse.com
- Format with spec-cleaner
- Fix build with new glibc 2.27 bsc#1079837:
  * guile-disable-int-tests.patch
- Use %%license macro to install license
* Fri Feb 17 2017 mpluskal@suse.com
- Update to version 2.0.14:
  * Bug fixes
    + Builds of .go files and of Guile itself are now
    bit-reproducible
    + 'number->locale-string' and 'monetary-amount->locale-string'
    fixes
    + (system base target) now recognizes "sh3" as a
    cross-compilation target
    + Fix race condition in '00-repl-server.test'
    + 'scandir' from (ice-9 ftw) no longer calls 'stat' for each
    entry
  * Several documentation improvements
- Drop no longer needed patches:
  * guile-fake-buildstamp.patch
  * repl-server-test.patch
- Small packaging cleanup with help of spec-cleaner
* Tue Nov  8 2016 schwab@suse.de
- repl-server-test.patch: fix race in 00-repl-server.test
* Sat Oct 15 2016 mpluskal@suse.com
- Update to version 2.0.13
  * Security fixes
    + CVE-2016-8606: REPL server now protects against HTTP
    inter-protocol attacks
    + CVE-2016-8605: 'mkdir' procedure no longer calls umask(2)
  * Several bugfixes and improvements (for details see NEWS file)
- Fetch keyring from savannah
- Use https for all urls
* Thu Jul 21 2016 sleep_walker@opensuse.org
- updated to 2.0.12:
  * * FFI: Add support for functions that set 'errno'
  * * The #!r6rs directive now influences read syntax
  * * 'read' now accepts "\(" as equivalent to "("
  * * SRFI-14 character data set upgraded to Unicode 8.0.0
  * * SRFI-19 table of leap seconds updated
  * * 'string-hash', 'read-string', and 'write' have been optimized
  * * GOOPS bug fix for inherited accessor methods
  for complete list of changes see NEWS
- refreshed patches
- add key of Andy Wingo to guile.keyring
* Wed Oct  7 2015 pgajdos@suse.com
- libguile require glibc-locale [bnc#948804]
* Mon Mar  9 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg signature
* Thu Feb  5 2015 pgajdos@suse.com
- use fake buildstamp [bnc#916347]
  + guile-fake-buildstamp.patch
* Tue Apr 22 2014 pgajdos@suse.com
- install libguile*-gdb.scm into
  %%{_datadir}/gdb/auto-load%%{_libdir}/  [bnc#874028]
* Mon Mar 31 2014 pgajdos@suse.com
- updated to 2.0.11:
  * * New GDB extension to support Guile
  * * Improved integration between R6RS and native Guile exceptions
  * * Support for HTTP proxies
  * * Lexical syntax improvements
  * ** Support |...| symbol notation
  * ** Support '#true' and '#false' notation for booleans.
  * ** Recognize '#\escape' character name.
  * ** Accept "\|" in string literals.
  * * Custom binary input ports now support 'setvbuf'.
  * * SRFI-4 predicates and length accessors no longer accept arrays.
  * * GUILE_PROGS now supports specifying a minimum required version.
  etc, see NEWS.
* Mon Apr 15 2013 pgajdos@suse.com
- updated to 2.0.9:
  * * New keyword arguments for procedures that open files
  * * Numerics improvements
  * * New optimizations
  * * `peek-char' no longer consumes EOF
  * * SLIB compatibility restored
  * * Better ,trace REPL command
  * * Better docstring syntax supported for `case-lambda'
  * * Improved handling of Unicode byte order marks
  etc. see NEWS for more/details
- removed unneeded gc-test.patch
* Tue Feb  5 2013 dmitry_r@opensuse.org
- move .so file to libguilereadline package [bnc#765436]
* Mon Dec 17 2012 pgajdos@suse.com
- fixed build: net-db.test takes EAI_SYSTEM error by
  * net-db-test.patch [bnc#794696]
- turn off one test in gc.test
  * gc-test.patch
    http://lists.gnu.org/archive/html/bug-guile/2012-07/msg00069.html
* Mon Dec  3 2012 pgajdos@suse.com
- update to 2.0.7:
  * Notable changes
  * * SRFI-105 curly infix expressions are supported
  * * Reader options may now be per-port
  * * Futures may now be nested
  * * `GUILE_LOAD_PATH' et al can now add directories to the end of
    the path
  * * `load-in-vicinity' search for `.go' files in `%%load-compiled-path'
  * * Extension search order fixed, and LD_LIBRARY_PATH preserved
  * * Optimize calls to `equal?' or `eqv?' with a constant argument
  * Manual updates
  * * SRFI-9 records now documented under "Compound Data Types"
  * * (ice-9 and-let-star) and (ice-9 curried-definitions) now documented
  * New interfaces
  * * New "functional record setters" as a GNU extension of SRFI-9
  * * web: New `http-get*', `response-body-port', and `text-content-type?'
    procedures
  * * `string-split' accepts character sets and predicates
  * * R6RS SRFI support
  * * `define-public' is no a longer curried definition by default
  etc. see NEWS
* Wed Jul 11 2012 pgajdos@suse.com
- update to 2.0.6:
  * Notable changes
  * * New optimization pass: common subexpression elimination (CSE)
  * * Improvements to the partial evaluator
  * * Run finalizers asynchronously in asyncs
  * * Update SRFI-14 character sets to Unicode 6.1
  * * Better source information for datums
  * * Improved error and warning messages
  * * A few important bug fixes in the HTTP modules.
  * * Pretty-print improvements
  * * Fix memory leak involving applicable SMOBs
  * * Support for HTTP/1.1 chunked transfer coding
  * * Micro-optimizations
  * * Incompatible change to `scandir'
  * New interfaces
  * * New C function: `scm_to_pointer'
  * * New C inline functions: `scm_new_smob', `scm_new_double_smob'
  * * (ice-9 format): Add ~h specifier for localized number output.
  * * (web response): New procedure: `response-must-not-include-body?'
  * * New predicate: 'supports-source-properties?'
  * * New C helpers: `scm_c_values', `scm_c_nvalues'
  * * Newly public inline C function: `scm_unget_byte'
  * * (language tree-il): New functions: `tree-il=?', `tree-il-hash'
  * * New fluid: `%%default-port-conversion-strategy'
  * * New syntax: `=>' within `case'
  * * (web http): `make-chunked-input-port', `make-chunked-output-port'
  * * (web http): `declare-opaque-header!'
  * New deprecations
  * * `close-io-port' deprecated
  * * `scm_sym2var' deprecated
  * * Lookup closures deprecated
  * Bug fixes
  * * Fix use of unitialized stat buffer in search-path of absolute paths.
  * * Avoid calling `freelocale' with a NULL argument.
  * * Work around erroneous tr_TR locale in Darwin 8 in tests.
  * * Fix `getaddrinfo' test for Darwin 8.
  * * Use Gnulib's `regex' module for better regex portability.
  * * `source-properties' and friends work on any object
  * * Rewrite open-process in C, for robustness related to threads and fork
  * * Fix <TAG>vector-length when applied to other uniform vector types
  * * Fix escape-only prompt optimization (was disabled previously)
  * * Fix a segfault when /dev/urandom is not accessible
  * * Fix flush on soft ports, so that it actually runs.
  * * Better compatibility of SRFI-9 records with core records
  * * Fix and clarify documentation of `sorted?'.
  * * Fix IEEE-754 endianness conversion in bytevectors.
  * * Correct thunk check in the `wind' instruction.
  * * Add @acronym support to texinfo modules
  * * Fix docbook->texi for <ulink> without URL
  * * Fix `setvbuf' to leave the line/column number unchanged.
  * * Add missing public declaration for `scm_take_from_input_buffers'.
  * * Fix relative file name canonicalization with empty %%LOAD-PATH entries.
  * * Import newer (ice-9 match) from Chibi-Scheme.
  * * Fix unbound variables and unbound values in ECMAScript runtime.
  * * Make SRFI-6 string ports Unicode-capable.
- removed patches:
  guile-turn-off-gc-test.patch
  guile-fix_fsf_add.patch
* Fri Jun 29 2012 coolo@suse.com
- libffi-devel is more generic than specific gcc versions (that no longer
  exist in factory)
* Mon Apr 23 2012 dvaleev@suse.com
- mark this threads test as unresolved since it may produce false
  negatives, depending on the behavior/timing of the garbage
  collector.
* Tue Jan 31 2012 pgajdos@suse.com
- update to 2.0.5:
  * * Better debuggability for interpreted procedures.
  * * Support for cross-compilation.
  * * The return of `local-eval'.
  * * Fluids can now have default values.
  * * Garbage collector tuning.
  * ** Unmanaged allocation
  * etc. see NEWS
* Wed Jan 18 2012 pgajdos@suse.com
- don't conflict with guile1 [bnc#724917]
* Fri Dec  9 2011 dimstar@opensuse.org
- Drop libtool archives.
* Sat Dec  3 2011 coolo@suse.com
- buildrequire ltdl-devel
* Mon Nov 28 2011 pgajdos@suse.com
- splitted out guile-modules-2_0 package [bnc#722306]
* Mon Nov 28 2011 pgajdos@suse.com
- ignore result of gc test
  * turn-off-gc-test.patch
* Tue Nov 15 2011 pgajdos@suse.com
- updated to 2.0.3:
  * * Guile has a new optimizer, `peval'.
  * * New module: `(web client)', a simple synchronous web client.
  * * Users can now install compiled `.go' files.
  * * Remove Front-Cover and Back-Cover text from the manual.
  * * More helpful `guild help'.
  * * New macro: `define-syntax-rule'
  * * The `,time' REPL meta-command now has more precision.
  * * `(ice-9 match)' can now match records.
  * * New module: `(language tree-il debug)'.
  * * New functions: `scm_is_exact', `scm_is_inexact'.
  * * Fix order of importing modules and resolving duplicates handlers.
  * * Fix a number of bugs involving extended (merged) generics.
  * * Fix invocation of merge-generics duplicate handler.
  * * Fix write beyond array end in arrays.c.
  * * Fix read beyond end of hashtable size array in hashtab.c.
  * * (web http): Locale-independent parsing and serialization of dates.
  * * Ensure presence of Host header in HTTP/1.1 requests.
  * * Fix take-right and drop-right for improper lists.
  * * Fix leak in get_current_locale().
  * * Fix recursive define-inlinable expansions.
  * * Check that srfi-1 procedure arguments are procedures.
  * * Fix r6rs `map' for multiple returns.
  * * Fix scm_tmpfile leak on POSIX platforms.
  * * Fix a couple of leaks (objcode->bytecode, make-boot-program).
  * * Fix guile-lib back-compatibility for module-stexi-documentation.
  * * Fix --listen option to allow other ports.
  * * Fix scm_to_latin1_stringn for substrings.
  * * Fix compilation of untyped arrays of rank not 1.
  * * Fix unparse-tree-il of <dynset>.
  * * Fix reading of #||||#.
  * * Fix segfault in GOOPS when class fields are redefined.
  * * Prefer poll(2) over select(2) to allow file descriptors above FD_SETSIZE.
* Fri Oct 14 2011 dimstar@opensuse.org
- Own %%{_datadir}/guile/site in order for slib not having issues
  registering itself.
* Thu Oct  6 2011 pgajdos@suse.com
- guile-devel requires guile [bnc#722306]
* Fri Sep 30 2011 davejplater@gmail.com
- Split off libguile-2_0-22 and libguilereadline-v-18-18 packages in
  preparation for bthe submission of legacy package guile.
- Cleaned spec file.
* Mon Aug 15 2011 pgajdos@novell.com
- updated to 2.0.2:
  * * `guile-tools' renamed to `guild'
  * * New control operators: `shift' and `reset'
  * * `while' as an expression
  * * Disallow access to handles of weak hash tables
  * * More precision for `get-internal-run-time', `get-internal-real-time'
  * * Guile now measures time spent in GC
  * * Add `gcprof'
  * * `map', `for-each' and some others now implemented in Scheme
  * * Add `scm_peek_byte_or_eof'.
  * * Implement #:stop-at-first-non-option option for getopt-long
  * * Improve R6RS conformance for conditions in the I/O libraries
  * * All deprecated routines emit warnings
  * * Constants in compiled code now share state better
  * * VLists: optimize `vlist-fold-right', and add `vhash-fold-right'
  * * UTF-8 ports to bypass `iconv' entirely
  * * Compiler speedups
  * * VM speed tuning
  * * SRFI-1 list-set optimizations
  * * `memq', `memv' optimizations
  * * Deprecate scm_whash API
  * * Deprecate scm_struct_table
  * * Deprecate scm_internal_dynamic_wind
  * * Deprecate scm_immutable_cell, scm_immutable_double_cell
  * * Fix double-loading of script in -ds case
  * * -x error message fix
  * * iconveh-related cross-compilation fixes
  * * Fix small integer return value packing on big endian machines.
  * * Fix hash-set! in weak-value table from non-immediate to immediate
  * * Fix call-with-input-file & relatives for multiple values
  * * Fix `hash' for inf and nan
  * * Fix libguile internal type errors caught by typing-strictness==2
  * * Fix compile error in MinGW fstat socket detection
  * * Fix generation of auto-compiled file names on MinGW
  * * Fix multithreaded access to internal hash tables
  * * Emit a 1-based line number in error messages
  * * Fix define-module ordering
  * * Fix several POSIX functions to use the locale encoding
  * * Add type and range checks to the complex generalized vector accessors
  * * Fix unaligned accesses for bytevectors of complex numbers
  * * Fix '(a #{.} b)
  * * Fix erroneous VM stack overflow for canceled threads
* Thu Jul 14 2011 pgajdos@novell.com
- updated to 2.0.1:
  * * REPL reader usability enhancements
  * * REPL output has configurable width
  * * Better C access to the module system
  * * Added `scm_call_5', `scm_call_6'
  * * Added `scm_from_latin1_keyword', `scm_from_utf8_keyword'
  * * R6RS unicode and string I/O work
  * * Added `pointer->scm', `scm->pointer' to `(system foreign)'
  * * Added `heap-allocated-since-gc' to `(gc-stats)'
  * * Add `on-error' REPL option
  * * Enforce immutability of string literals
  * * Fix pthread redirection
  * * `with-continuation-barrier' now unwinds on `quit'
  * * `string->pointer' and `pointer->string' have optional encoding arg
  * * R6RS fixnum arithmetic optimizations
  * * New procedure: `define-inlinable'
  * * New procedure: `exact-integer-sqrt'
  * * "Extended read syntax" for symbols parses better
  * * Added `--fresh-auto-compile' option
  * * etc., see ChangeLog and NEWS
* Mon Mar 22 2010 pgajdos@suse.cz
- fixed build with new gcc
* Tue Jan 26 2010 pgajdos@suse.cz
- fixed build:
  "Earlier versions of ltdl would look for extensions under $PWD; this
  behavior changed in 2.2.6b."
  * testsuite-build.patch taken from guile git (1.8 branch)
* Mon Nov 30 2009 pgajdos@suse.cz
- updated to 1.8.7 (see NEWS)
- fixed testsuite with patch taken from Fedora
  * popen-test.patch
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Jun 16 2009 pgajdos@suse.cz
- Updated to 1.8.6 (see NEWS)
  - removed ac.patch
* Sat Feb  7 2009 schwab@suse.de
- Rebuild broken info files.
- Fix %%post scripts.
* Fri Jan 16 2009 crrodriguez@suse.de
-  remove static libraries
- run make check
* Sun Sep  7 2008 schwab@suse.de
- Fix conflicting options.
* Mon Jul  7 2008 pgajdos@suse.cz
- updated to 1.8.5:
  * new modules `(srfi srfi-88)'
  * New `postfix' read option, for SRFI-88 keyword syntax
  * Some I/O primitives have been inlined, which improves I/O performance
  * New object-based traps infrastructure
  * New support for working on Guile code from within Emacs
  * bug fixes
* Thu Mar 13 2008 schwab@suse.de
- Use autoreconf.
* Thu Feb 28 2008 ro@suse.de
- update to 1.8.4:
  * New modules (srfi srfi-69)
  * Bug fixes
- fix code for recent gcc by checking for __GNUC_GNU_INLINE__
  instead of __GNUC__ for inline specifics (thanks, richi)
* Mon Feb  4 2008 pgajdos@suse.cz
- guile conflicts with slib < 3a5 [#354936]
* Wed Dec 12 2007 pgajdos@suse.cz
- upgraded to 1.8.3:
  * New modules (srfi srfi-35), (srfi srfi-37)
  * Bug fixes
  * The reader is now faster, which reduces startup time
  * Procedures returned by `record-accessor' and `record-modifier'
    are faster
  * New procedures set-program-arguments, make-vtable
  * Incompatible change:
    ~~~~~~~~~~~~~~~~~~~~
    The body of a top-level `define' no longer sees the binding
    being created. In a top-level `define', the binding being
    created is no longer visible from the `define' body. This
    breaks code like "(define foo (begin (set! foo 1) (+ foo 1)))",
    where `foo' is now unbound in the body. However, such code
    was not R5RS-compliant anyway, per Section 5.2.1.
- removed getcontext.patch -- no longer needed because
  of code change
* Mon Mar  5 2007 sbrabec@suse.cz
- Slib guile library installation moved from guile to slib.
* Thu Jan 11 2007 sbrabec@suse.cz
- More spec file cleanups.
* Fri Dec  8 2006 maw@suse.de
- Clean up the spec, removing some hardcoded paths.
* Tue Nov 28 2006 sbrabec@suse.cz
- Build as user and do not alter root filesystem.
* Mon Nov 27 2006 sbrabec@suse.cz
- Created empty directory for site packages (#223837).
* Thu Nov 23 2006 sbrabec@suse.cz
- Fixed slib installation scriptlets (#214940).
* Wed Nov  8 2006 anicka@suse.cz
- moved .la files to the base package (#218032).
* Wed Oct 25 2006 sbrabec@suse.cz
- Moved .so files to the base package (#214940).
* Mon Oct 16 2006 anicka@suse.cz
- move /usr/share/guile from devel to main package
  (fixes ##212545)
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Fri Oct 13 2006 schwab@suse.de
- Add split provide.
* Fri Oct 13 2006 aj@suse.de
- Split up devel subpackage.
* Tue Oct 10 2006 sbrabec@suse.cz
- Updated to version 1.8.1:
  * LFS functions are now used to access 64-bit files on 32-bit
    systems.
  * New procedures and functions.
  * New modules and module merges.
  * API changes.
  * Bugs fixed.
  * Guile is now licensed with the GNU Lesser General
    Public License.
  * The manual is now licensed with the GNU Free Documentation
    License.
  * Guile now requires GNU MP.
  * Guile now has separate private and public configuration
    headers.
  * Thread implementation has changed.
  * Command line syntax changes.
* Fri Oct  6 2006 anicka@suse.cz
- update to 1.6.8
  * gcc 4.0 fixes
  * Guile now allows multiple line comments to end without
    a trailing newline.
  * better support for new versions of SLIB
  * changes in C interface
* Fri Sep  8 2006 anicka@suse.cz
- rewrite SuSEconfig.guile to RPM triggers
* Sun Jul 16 2006 schwab@suse.de
- Mark ia64_getcontext as returning twice.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 ro@suse.de
- add aclocal in libltdl
* Wed May 18 2005 sbrabec@suse.cz
- Disabled randomly failing make -j.
* Tue Apr  5 2005 sbrabec@suse.cz
- Fixed incomplete array element type.
* Thu Mar 24 2005 uli@suse.de
- fixed to build on ARM
* Fri Jan 21 2005 sbrabec@suse.cz
- Updated to version 1.6.7.
* Fri Dec 10 2004 meissner@suse.de
- make -j , added make check.
* Tue Mar 30 2004 sbrabec@suse.cz
- Fixed tempfile creation in guile-snarf (#36367).
- Build with -fno-strict-aliasing.
* Thu Nov  6 2003 schwab@suse.de
- Fix syntax in configure script.
* Tue Jul  8 2003 sbrabec@suse.cz
- Updated to version 1.6.4.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Wed Mar 12 2003 sbrabec@suse.cz
- Workaround guile-config info version bug (symlink, fixes bug 25190).
* Tue Feb 11 2003 sbrabec@suse.cz
- Fixed GUILEVERSION datadir path.
* Mon Feb 10 2003 sbrabec@suse.cz
- Updated to version 1.6.2.
- Use %%install_info (bug #23423).
* Wed Dec 11 2002 garloff@suse.de
- Make slib integration work independent of guile version number.
* Wed Dec  4 2002 sbrabec@suse.cz
- Change error message for unknown platform to warning. It allows to
  compile guile on all platforms, but there is no guarantee to
  functionallity. (guile-platforms.diff)
* Tue Dec  3 2002 sbrabec@suse.cz
- Fixed typo, which breaks TeXmacs
  (guile-1.6.0-top_srcdir_absolute.diff).
* Wed Oct 30 2002 sbrabec@suse.cz
- Update to version 1.6.0.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Tue Jul 30 2002 mcihar@suse.cz
- fixed SuSEconfig.guile for new version
* Wed Jul 17 2002 tiwai@suse.de
- updated to version 1.4.1.
* Tue Jun 11 2002 mcihar@suse.cz
- disabled qthreads for ppc64
* Mon Apr 29 2002 sf@suse.de
- disabled qthreads for x86_64
* Thu Apr  4 2002 pmladek@suse.cz
- moved AC_LIBOBJ after AC_PROG_CC because AC_LIBOBJ uses $ac_objext
* Wed Apr  3 2002 pmladek@suse.cz
- fixed to compile with autoconf-2.53 (AC_LIBOBJ vs. LIBOBJS)
* Fri Feb  8 2002 pmladek@suse.cz
- used -a option with automake to fix for PLUS distribution
- added back guile-doc-snarf: work around problem with cpp on ia64
  bebause of 7.2-ia64+kde distribution
* Wed Feb  6 2002 schwab@suse.de
- Don't add /usr/include and /usr/local/include to include search path.
- Avoid trigraph.
- Add support for ia64 register backing store (from cvs).
- Don't build with -O0 on ia64.
* Mon Dec 17 2001 froh@suse.de
- added %%{_libdir} to the specfile where appropriate to make it lib64
  clean.
* Fri Dec  7 2001 pmladek@suse.cz
- fixed for new position of slib library
- SuSEconfig.guile uses check_md5_and_move now
- removed unused package scheme from neededforbuild
* Tue Nov  6 2001 pmladek@suse.cz
- fixed to compile with automake 1.5:
  * OMIT_DEPENDENCIES are not supported now
* Sat Sep 15 2001 schwab@suse.de
- Fix libtool configuration.
- Remove ia64 cpp workaround.
- Fix hash functions for 64-bit architectures.
* Fri Aug 31 2001 pmladek@suse.cz
- fixed creating of SLIB catalog (#8997):
  - moved from triggerin to SuSEconfig because
  there were problems with update when rpm was
  updated after guile
* Mon Aug 27 2001 pmladek@suse.cz
- fixed to compile on axp:
  * fixed file numbering in qt/md/axp.s
  * fixed end of block qt_vstart in qt/md/axp.s
* Fri Aug 10 2001 ro@suse.de
- fixed to build with current autoconf and libtool
* Thu Jun 14 2001 pmladek@suse.cz
- fixed to more correctly compile with new autoconf
* Mon Jun 11 2001 pmladek@suse.cz
- fixed to compile with new autoconf
* Sat May 12 2001 schwab@suse.de
- Fix readline interface.
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Wed Dec  6 2000 schwab@suse.de
- guile-doc-snarf: work around problem with cpp on ia64.
- Build with -O0 on ia64.
* Thu Nov 23 2000 cihlar@suse.cz
- fixed to compile on older distros
* Sun Nov 12 2000 ro@suse.de
- don't redeclare inet_aton
* Wed Nov  8 2000 ro@suse.de
- changed %%post to %%triggerin -- scheme
* Tue Nov  7 2000 cihlar@suse.cz
- added postinstall and link to /usr/lib/scheme/slib
* Fri Nov  3 2000 cihlar@suse.cz
- bzipped sources
- clean up spec file
* Mon Oct 23 2000 ro@suse.de
- use macro for infodir
* Wed Aug  2 2000 cihlar@suse.cz
- update to version 1.4
* Fri Apr  7 2000 bk@suse.de
- And no QuickThreads yet on s390 too ;-)
* Thu Apr  6 2000 schwab@suse.de
- No QuickThreads yet on ia64.
* Mon Mar  6 2000 schwab@suse.de
- Update config.{guess,sub} from automake.
* Sun Feb  6 2000 ke@suse.de
- Add group tag.
- /configure -> %%build.
- use /usr/share/info.
* Sun Oct  3 1999 ke@suse.de
- update: 1.3.4.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Sep  7 1999 uli@suse.de
- no QuickThreads on PPC, disabled them
* Wed Aug 25 1999 ro@suse.de
- fixed configuration for alpha-Quickthreads again
* Wed Aug 25 1999 ke@suse.de
- update: 1.3.2.
* Wed Mar 17 1999 ro@suse.de
- fixed patch-call
* Wed Feb 10 1999 ke@suse.de
- apply guile-slow-read-fix.patch (by Harvey J. Stein
  <hjstein@bfr.co.il>).
- fix lib perms.
* Fri Feb  5 1999 ro@suse.de
- changed config to detect alpha(ev56)  as alpha
* Wed Oct 21 1998 ke@suse.de
- update: version 1.3.
- build libqthreads.
* Wed Sep 23 1998 ke@suse.de
- update: snapshot 1998-09-23 (1.3a).
* Sun Aug 23 1998 ke@suse.de
- update: snapshot 1998-08-23 (1.3a).
* Fri Nov 21 1997 bs@suse.de
- don't call ldconfig in spec file
* Tue Jul 15 1997 Karl Eichwalder  <ke@suse.de>
  * initial package: version 1.2.
